@@ -182,6 +182,7 @@ pub struct LevelConfig {
     config: HashMap<String, LevelFilter>,
     generation: u64,
     origin_generation: u64,
+    default_display_level: Option<LevelFilter>,
 }
 impl LevelConfig {
     /// Create an empty LevelConfig.
@@ -190,6 +191,7 @@ impl LevelConfig {
             config: HashMap::new(),
             generation: 0,
             origin_generation: 0,
+            default_display_level: None,
         }
     }
     /// Set for a given target the LevelFilter in the table and update the generation.
@@ -204,6 +206,10 @@ impl LevelConfig {
         self.config.insert(target.to_string(), level);
         self.generation += 1;
     }
+    /// Set default display level filter for new targets - independent from recording
+    pub fn set_default_display_level(&mut self, level: LevelFilter) {
+        self.default_display_level = Some(level);
+    }
     /// Retrieve an iter for all the targets stored in the hash table.
     pub fn keys(&self) -> Keys<String, LevelFilter> {
         self.config.keys()
@@ -229,7 +235,17 @@ impl LevelConfig {
                         continue;
                     }
                 }
-                self.set(target, *origin_levelfilter);
+                let levelfilter = self
+                    .default_display_level
+                    .map(|lvl| {
+                        if lvl > *origin_levelfilter {
+                            *origin_levelfilter
+                        } else {
+                            lvl
+                        }
+                    })
+                    .unwrap_or(*origin_levelfilter);
+                self.set(target, levelfilter);
             }
             self.generation = origin.generation;
         }
@@ -526,7 +542,11 @@ impl TuiWidgetState {
             inner: Arc::new(Mutex::new(TuiWidgetInnerState::new())),
         }
     }
-    pub fn set_level_for_target(&self, target: &str, levelfilter: LevelFilter) -> &TuiWidgetState {
+    pub fn set_default_display_level(self, levelfilter: LevelFilter) -> TuiWidgetState {
+        self.inner.lock().config.default_display_level = Some(levelfilter);
+        self
+    }
+    pub fn set_level_for_target(self, target: &str, levelfilter: LevelFilter) -> TuiWidgetState {
         self.inner.lock().config.set(target, levelfilter);
         self
     }
@@ -707,8 +727,8 @@ impl<'b> Widget for TuiLoggerTargetWidget<'b> {
             let targets = &(&state.config);
             for i in 0..list_height {
                 let t = &self.targets[i + offset];
-                let hot_level_filter = hot_targets.get(&t).unwrap();
-                let level_filter = targets.get(&t).unwrap();
+                let hot_level_filter = hot_targets.get(t).unwrap();
+                let level_filter = targets.get(t).unwrap();
                 for (j, sym, lev) in &[
                     (0, "E", Level::Error),
                     (1, "W", Level::Warn),
@@ -758,7 +778,7 @@ impl<'b> Widget for TuiLoggerTargetWidget<'b> {
 #[derive(Debug, Clone, PartialEq, Hash)]
 pub enum TuiLoggerLevelOutput {
     Abbreviated,
-    Long
+    Long,
 }
 
 pub struct TuiLoggerWidget<'b> {
@@ -967,11 +987,11 @@ impl<'b> TuiLoggerWidget<'b> {
             log::Level::Trace => (self.style_trace, "TRACE", "T", true),
         };
         if let Some(fmt) = self.format_timestamp.as_ref() {
-            output.push_str(&format!("{}", evt.timestamp.format(&fmt)));
+            output.push_str(&format!("{}", evt.timestamp.format(fmt)));
             output.push(self.format_separator);
         }
         match &self.format_output_level {
-            None => {},
+            None => {}
             Some(TuiLoggerLevelOutput::Abbreviated) => {
                 output.push_str(lev_abbr);
                 output.push(self.format_separator);
@@ -1275,20 +1295,16 @@ impl<'a> Widget for TuiLoggerSmartWidget<'a> {
     fn render(self, area: Rect, buf: &mut Buffer) {
         let entries_s = {
             let mut tui_lock = TUI_LOGGER.inner.lock();
-            let first_timestamp = {
-                if let Some(entry) = tui_lock.events.iter().next() {
-                    Some(entry.timestamp.timestamp_millis())
-                } else {
-                    None
-                }
-            };
-            let last_timestamp = {
-                if let Some(entry) = tui_lock.events.rev_iter().next() {
-                    Some(entry.timestamp.timestamp_millis())
-                } else {
-                    None
-                }
-            };
+            let first_timestamp = tui_lock
+                .events
+                .iter()
+                .next()
+                .map(|entry| entry.timestamp.timestamp_millis());
+            let last_timestamp = tui_lock
+                .events
+                .rev_iter()
+                .next()
+                .map(|entry| entry.timestamp.timestamp_millis());
             if let Some(first) = first_timestamp {
                 if let Some(last) = last_timestamp {
                     let dt = last - first;
